@@ -1,8 +1,12 @@
 package YAML::Base;
-use strict; use warnings;
-use base 'Exporter';
 
-our @EXPORT = qw(field XXX);
+use strict;
+use warnings;
+use Exporter ();
+
+our $VERSION = '0.70';
+our @ISA     = 'Exporter';
+our @EXPORT  = qw(field XXX);
 
 sub new {
     my $class = shift;
@@ -129,9 +133,9 @@ $_scalar_info = sub {
 };
 
 $_new_error = sub {
+    require Carp;
     my $self = shift;
     require YAML::Error;
-    require Carp;
 
     my $code = shift || 'unknown error';
     my $error = YAML::Error->new(code => $code);
@@ -167,6 +171,8 @@ $default_as_code = sub {
     return $code;
 };
 
+1;
+
 __END__
 
 =head1 NAME
