@@ -1,20 +1,24 @@
 package YAML::Dumper;
-use strict; use warnings;
-use YAML::Base;
-use base 'YAML::Dumper::Base';
 
+use strict;
+use warnings;
+use YAML::Base;
+use YAML::Dumper::Base;
 use YAML::Node;
 use YAML::Types;
 
+our $VERSION = '0.70';
+our @ISA     = 'YAML::Dumper::Base';
+
 # Context constants
-use constant KEY => 3;
-use constant BLESSED => 4;
+use constant KEY       => 3;
+use constant BLESSED   => 4;
 use constant FROMARRAY => 5;
-use constant VALUE => "\x07YAML\x07VALUE\x07";
+use constant VALUE     => "\x07YAML\x07VALUE\x07";
 
 # Common YAML character sets
 my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f]';
-my $LIT_CHAR = '|';    
+my $LIT_CHAR    = '|';    
 
 #==============================================================================
 # OO version of Dump. YAML->new->dump($foo); 
