@@ -1,20 +1,25 @@
 package YAML::Marshall;
-use strict; use warnings;
-use Class::Spiffy -base;
-use YAML::Node();
+
+use strict;
+use warnings;
+use YAML::Node ();
+
+our $VERSION = '0.70';
 
 sub import {
-    my ($package, $mixin, $tag) = @_;
-    if ($mixin eq '-mixin' && $tag) {
-        my $class = caller;
-        no warnings 'once';
-        $YAML::TagClass->{$tag} = $class;
-        no strict 'refs';
-        ${$class . "::YamlTag"} = $tag;
-        pop @_;
+    my $class = shift;
+    no strict 'refs';
+    my $package = caller;
+    unless (grep { $_ eq $class} @{$package . '::ISA'}) {
+        push @{$package . '::ISA'}, $class;
     }
 
-    goto &Class::Spiffy::import;
+    my $tag = shift;
+    if ( $tag ) {
+        no warnings 'once';
+        $YAML::TagClass->{$tag} = $package;
+        ${$package . "::YamlTag"} = $tag;
+    }
 }
 
 sub yaml_dump {
