@@ -1,9 +1,14 @@
 package YAML::Node;
-use strict; use warnings;
-use YAML::Base -base;
+
+use strict;
+use warnings;
+
+use YAML::Base;
 use YAML::Tag;
 
-our @EXPORT = qw(ynode);
+our $VERSION = '0.70';
+our @ISA     = 'YAML::Base';
+our @EXPORT  = qw(ynode);
 
 sub ynode {
     my $self;
@@ -62,6 +67,7 @@ sub keys {
 
 #==============================================================================
 package yaml_scalar;
+
 @yaml_scalar::ISA = qw(YAML::Node);
 
 sub new {
@@ -87,6 +93,7 @@ sub STORE {
 
 #==============================================================================
 package yaml_sequence;
+
 @yaml_sequence::ISA = qw(YAML::Node);
 
 sub new {
@@ -126,6 +133,7 @@ sub undone {
 
 #==============================================================================
 package yaml_mapping;
+
 @yaml_mapping::ISA = qw(YAML::Node);
 
 sub new {
@@ -286,6 +294,7 @@ Ingy döt Net <ingy@cpan.org>
 =head1 COPYRIGHT
 
 Copyright (c) 2006. Ingy döt Net. All rights reserved.
+
 Copyright (c) 2002. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
