@@ -1,5 +1,10 @@
 package YAML::Tag;
 
+use strict;
+use warnings;
+
+our $VERSION = '0.70';
+
 use overload '""' => sub { ${$_[0]} };
 
 sub new {
